//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenResult](index.md)/[shantenInfo](shanten-info.md)

# shantenInfo

[common]\
abstract val [shantenInfo](shanten-info.md): [S](index.md)

向听信息
